@@ -35,8 +35,8 @@
 
 #include "gtksourcecompletioncontainer.h"
 
-#define MAX_WIDTH  350
-#define MAX_HEIGHT 180
+#define UNREALIZED_WIDTH  350
+#define MAX_HEIGHT        180
 
 struct _GtkSourceCompletionContainerPrivate
 {
@@ -46,6 +46,30 @@ struct _GtkSourceCompletionContainerPrivate
 
 G_DEFINE_TYPE_WITH_PRIVATE (GtkSourceCompletionContainer, _gtk_source_completion_container, GTK_TYPE_BIN);
 
+static gint
+get_max_width (GtkSourceCompletionContainer *container)
+{
+	if (gtk_widget_get_realized (GTK_WIDGET (container)))
+	{
+		GtkWidget *toplevel;
+		GdkWindow *window;
+		GdkScreen *screen;
+		gint max_width;
+		gint xorigin;
+
+		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (container));
+		window = gtk_widget_get_window (toplevel);
+		screen = gdk_window_get_screen (window);
+
+		gdk_window_get_origin (window, &xorigin, NULL);
+		max_width = gdk_screen_get_width (screen) - xorigin;
+
+		return MAX (max_width, UNREALIZED_WIDTH);
+	}
+
+	return UNREALIZED_WIDTH;
+}
+
 /* gtk_container_add() is overridden. This function calls the GtkBin's add(). */
 static void
 bin_container_add (GtkContainer *container,
@@ -124,7 +148,7 @@ static void
 check_scrolled_window (GtkSourceCompletionContainer *container,
 		       GtkRequisition                child_size)
 {
-	if (child_size.width <= MAX_WIDTH &&
+	if (child_size.width <= get_max_width (container) &&
 	    child_size.height <= MAX_HEIGHT)
 	{
 		remove_scrolled_window (container);
@@ -168,7 +192,7 @@ _gtk_source_completion_container_get_preferred_width (GtkWidget *widget,
 		width += get_vertical_scrollbar_width ();
 	}
 
-	width = MIN (width, MAX_WIDTH);
+	width = MIN (width, get_max_width (container));
 
 	if (min_width != NULL)
 	{
@@ -181,6 +205,38 @@ _gtk_source_completion_container_get_preferred_width (GtkWidget *widget,
 	}
 }
 
+static gint
+get_row_height (GtkSourceCompletionContainer *container)
+{
+	GList *columns = gtk_tree_view_get_columns (container->priv->tree_view);
+	GList *l;
+	gint max_row_height = 0;
+	gint vertical_separator = 0;
+
+	for (l = columns; l != NULL; l = l->next)
+	{
+		GtkTreeViewColumn *column = l->data;
+		gint row_height;
+
+		gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, &row_height);
+
+		if (row_height > max_row_height)
+		{
+			max_row_height = row_height;
+		}
+	}
+
+	gtk_widget_style_get (GTK_WIDGET (container->priv->tree_view),
+			      "vertical-separator", &vertical_separator,
+			      NULL);
+
+	max_row_height += vertical_separator;
+
+	g_list_free (columns);
+
+	return max_row_height;
+}
+
 /* Return a height at a row boundary of the GtkTreeView. */
 static void
 _gtk_source_completion_container_get_preferred_height (GtkWidget *widget,
@@ -188,12 +244,10 @@ _gtk_source_completion_container_get_preferred_height (GtkWidget *widget,
 						       gint	 *nat_height)
 {
 	GtkSourceCompletionContainer *container = GTK_SOURCE_COMPLETION_CONTAINER (widget);
-	GtkTreeViewColumn *column;
 	GtkTreeModel *model;
 	GtkRequisition nat_size;
 	gint nb_rows = 0;
 	gint row_height = 0;
-	gint vertical_separator = 0;
 	gint scrollbar_height = 0;
 	gint total_height = 0;
 	gint ret_height = 0;
@@ -208,21 +262,6 @@ _gtk_source_completion_container_get_preferred_height (GtkWidget *widget,
 		*nat_height = 0;
 	}
 
-	column = gtk_tree_view_get_column (container->priv->tree_view, 0);
-
-	if (column == NULL)
-	{
-		return;
-	}
-
-	gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, &row_height);
-
-	gtk_widget_style_get (GTK_WIDGET (container->priv->tree_view),
-			      "vertical-separator", &vertical_separator,
-			      NULL);
-
-	row_height += vertical_separator;
-
 	model = gtk_tree_view_get_model (container->priv->tree_view);
 
 	if (model == NULL)
@@ -230,6 +269,8 @@ _gtk_source_completion_container_get_preferred_height (GtkWidget *widget,
 		return;
 	}
 
+	row_height = get_row_height (container);
+
 	nb_rows = gtk_tree_model_iter_n_children (model, NULL);
 
 	total_height = nb_rows * row_height;
@@ -240,7 +281,7 @@ _gtk_source_completion_container_get_preferred_height (GtkWidget *widget,
 
 	check_scrolled_window (container, nat_size);
 
-	if (MAX_WIDTH < nat_size.width)
+	if (get_max_width (container) < nat_size.width)
 	{
 		scrollbar_height = get_horizontal_scrollbar_height ();
 		total_height += scrollbar_height;
