@@ -27,27 +27,27 @@
 #include "gtksourcegutterrenderer.h"
 #include "gtksourcegutterrenderer-private.h"
 
-#include <gobject/gvaluecollector.h>
-
 /**
  * SECTION:gutter
  * @Short_description: Gutter object for #GtkSourceView
  * @Title: GtkSourceGutter
- * @See_also:#GtkSourceView
+ * @See_also: #GtkSourceView, #GtkSourceMark
  *
- * The #GtkSourceGutter object represents the left and right gutters of the text
- * view. It is used by #GtkSourceView to draw the line numbers and category
- * marks that might be present on a line. By packing additional #GtkSourceGutterRenderer
- * objects in the gutter, you can extend the gutter with your own custom
- * drawings.
+ * The #GtkSourceGutter object represents the left or right gutter of the text
+ * view. It is used by #GtkSourceView to draw the line numbers and
+ * #GtkSourceMark<!-- -->s that might be present on a line. By packing
+ * additional #GtkSourceGutterRenderer objects in the gutter, you can extend the
+ * gutter with your own custom drawings.
+ *
+ * To get a #GtkSourceGutter, use the gtk_source_view_get_gutter() function.
  *
  * The gutter works very much the same way as cells rendered in a #GtkTreeView.
  * The concept is similar, with the exception that the gutter does not have an
  * underlying #GtkTreeModel. The builtin line number renderer is at position
  * #GTK_SOURCE_VIEW_GUTTER_POSITION_LINES (-30) and the marks renderer is at
- * #GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS (-20). You can use these values to
- * position custom renderers accordingly.
- *
+ * #GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS (-20). The gutter sorts the renderers
+ * in ascending order, from left to right. So the marks are displayed on the
+ * right of the line numbers.
  */
 
 /* Properties */
@@ -244,12 +244,6 @@ renderer_free (Renderer *renderer)
 	g_slice_free (Renderer, renderer);
 }
 
-static void
-gtk_source_gutter_finalize (GObject *object)
-{
-	G_OBJECT_CLASS (gtk_source_gutter_parent_class)->finalize (object);
-}
-
 static void
 gtk_source_gutter_dispose (GObject *object)
 {
@@ -412,12 +406,7 @@ calculate_gutter_size (GtkSourceGutter  *gutter,
 			g_array_append_val (sizes, width);
 		}
 
-		total_width += width + gutter->priv->xpad;
-	}
-
-	if (gutter->priv->renderers)
-	{
-		total_width += gutter->priv->xpad;
+		total_width += width;
 	}
 
 	return total_width;
@@ -531,14 +520,13 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 	object_class->set_property = gtk_source_gutter_set_property;
 	object_class->get_property = gtk_source_gutter_get_property;
 
-	object_class->finalize = gtk_source_gutter_finalize;
 	object_class->dispose = gtk_source_gutter_dispose;
 	object_class->constructed = gtk_source_gutter_constructed;
 
 	/**
 	 * GtkSourceGutter:view:
 	 *
-	 * The #GtkSourceView of the gutter
+	 * The #GtkSourceView of the gutter.
 	 */
 	g_object_class_install_property (object_class,
 	                                 PROP_VIEW,
@@ -554,7 +542,7 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 	/**
 	 * GtkSourceGutter:window-type:
 	 *
-	 * The text window type on which the window is placed
+	 * The text window type on which the window is placed.
 	 */
 	g_object_class_install_property (object_class,
 	                                 PROP_WINDOW_TYPE,
@@ -565,6 +553,14 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 	                                                    0,
 	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
+	/**
+	 * GtkSourceGutter:xpad:
+	 *
+	 * The x-padding.
+	 *
+	 * Deprecated: 3.12: Use the #GtkSourceGutterRenderer:xpad property
+	 * instead.
+	 */
 	g_object_class_install_property (object_class,
 	                                 PROP_XPAD,
 	                                 g_param_spec_int ("xpad",
@@ -575,7 +571,14 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 	                                                   0,
 	                                                   G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
-
+	/**
+	 * GtkSourceGutter:ypad:
+	 *
+	 * The y-padding.
+	 *
+	 * Deprecated: 3.12: Use the #GtkSourceGutterRenderer:ypad property
+	 * instead.
+	 */
 	g_object_class_install_property (object_class,
 	                                 PROP_YPAD,
 	                                 g_param_spec_int ("ypad",
@@ -635,6 +638,13 @@ gtk_source_gutter_new (GtkSourceView     *view,
 	                     NULL);
 }
 
+static GdkWindow *
+get_window (GtkSourceGutter *gutter)
+{
+	return gtk_text_view_get_window (GTK_TEXT_VIEW (gutter->priv->view),
+	                                 gutter->priv->window_type);
+}
+
 /* Public API */
 
 /**
@@ -648,6 +658,7 @@ gtk_source_gutter_new (GtkSourceView     *view,
  * if the gutter has no window.
  *
  * Since: 2.8
+ * Deprecated: 3.12: Use gtk_text_view_get_window() instead.
  */
 GdkWindow *
 gtk_source_gutter_get_window (GtkSourceGutter *gutter)
@@ -655,8 +666,7 @@ gtk_source_gutter_get_window (GtkSourceGutter *gutter)
 	g_return_val_if_fail (GTK_SOURCE_IS_GUTTER (gutter), NULL);
 	g_return_val_if_fail (gutter->priv->view != NULL, NULL);
 
-	return gtk_text_view_get_window (GTK_TEXT_VIEW (gutter->priv->view),
-	                                 gutter->priv->window_type);
+	return get_window (gutter);
 }
 
 /**
@@ -674,7 +684,6 @@ gtk_source_gutter_get_window (GtkSourceGutter *gutter)
  * Since: 3.0
  *
  **/
-
 gboolean
 gtk_source_gutter_insert (GtkSourceGutter         *gutter,
                           GtkSourceGutterRenderer *renderer,
@@ -945,7 +954,7 @@ on_view_draw (GtkSourceView   *view,
 	GdkDeviceManager *device_manager;
 	GdkDevice *pointer;
 
-	window = gtk_source_gutter_get_window (gutter);
+	window = get_window (gutter);
 
 	if (window == NULL || !gtk_cairo_should_draw_window (cr, window))
 	{
@@ -1008,7 +1017,7 @@ on_view_draw (GtkSourceView   *view,
 	                                    &start,
 	                                    &end);
 
-	cell_area.x = gutter->priv->xpad;
+	cell_area.x = 0;
 	cell_area.height = background_area.height;
 
 	gtk_text_view_buffer_to_window_coords (text_view,
@@ -1379,7 +1388,7 @@ redraw_for_window (GtkSourceGutter *gutter,
 	gboolean redraw;
 	gint start;
 
-	if (event->window != gtk_source_gutter_get_window (gutter) && act_on_window)
+	if (event->window != get_window (gutter) && act_on_window)
 	{
 		return FALSE;
 	}
@@ -1480,7 +1489,7 @@ on_view_button_press_event (GtkSourceView    *view,
 	gint start = -1;
 	GdkRectangle rect;
 
-	if (event->window != gtk_source_gutter_get_window (gutter))
+	if (event->window != get_window (gutter))
 	{
 		return FALSE;
 	}
@@ -1582,6 +1591,14 @@ on_view_style_updated (GtkSourceView   *view,
 	gtk_source_gutter_queue_draw (gutter);
 }
 
+/**
+ * gtk_source_gutter_set_padding:
+ * @gutter:
+ * @xpad:
+ * @ypad:
+ *
+ * Deprecated: 3.12: Use gtk_source_gutter_renderer_set_padding() instead.
+ */
 void
 gtk_source_gutter_set_padding (GtkSourceGutter *gutter,
                                gint             xpad,
@@ -1595,6 +1612,14 @@ gtk_source_gutter_set_padding (GtkSourceGutter *gutter,
 	}
 }
 
+/**
+ * gtk_source_gutter_get_padding:
+ * @gutter:
+ * @xpad:
+ * @ypad:
+ *
+ * Deprecated: 3.12: Use gtk_source_gutter_renderer_get_padding() instead.
+ */
 void
 gtk_source_gutter_get_padding (GtkSourceGutter *gutter,
                                gint            *xpad,
@@ -1623,6 +1648,9 @@ gtk_source_gutter_get_padding (GtkSourceGutter *gutter,
  *
  * Returns: (transfer none): the renderer at (x, y) or %NULL.
  */
+/* FIXME: to insert a renderer in a gutter, only one position is needed. Here to
+ * retrieve a renderer, two positions are needed? Document why.
+ */
 GtkSourceGutterRenderer *
 gtk_source_gutter_get_renderer_at_pos (GtkSourceGutter *gutter,
                                        gint             x,
